@@ -1,5 +1,5 @@
 package CMS::Drupal::Types;
-$CMS::Drupal::Types::VERSION = '0.92';
+$CMS::Drupal::Types::VERSION = '0.93';
 # ABSTRACT: A Perl type library for working with Drupal
 
 use strict;
@@ -33,8 +33,8 @@ declare DBHost, as Optional[Str],
 declare DBPort, as Optional[Int],
   message { 'The port number must be an integer. ' };
 
-declare DBPrefix, as Optional[StrMatch[ qr/ \w+_ /x ]],
-  message { return 'The table prefix must end in an underscore. ' };
+declare DBPrefix, as Optional[Str],
+  message { return 'The table prefix must be a string. ' };
 
 1; ## return true to end package CMS::Drupal::Types
 
@@ -50,7 +50,7 @@ CMS::Drupal::Types - A Perl type library for working with Drupal
 
 =head1 VERSION
 
-version 0.92
+version 0.93
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ B<DBPort>
  Must be an integer if present. May be empty. May be omitted.
 
 B<DBPrefix>
- Must be a string ending in an underscore if present. May be omitted.
+ Must be a string if present. May be omitted.
 
 =head1 SEE ALSO
 
